==> tecfy_corev2_package-1.1.30.tar.gz: lib/models/entity/property_time.model.dart <==
part of tecfy_corev2_client_package;

class PropertyTime extends Property {
  /// <summary>
  /// HH:mm    (default)
  /// dd/MM/yyyy
  /// </summary>
  late String format;

  PropertyTime(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.format = "HH:mm"})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyTime.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    int? date = data[dbName] is int
        ? data[dbName]
        : int.tryParse(data[dbName]?.toString() ?? '');

    if (date == null) return '';
    var time = DateTime.utc(0, 0, 0, date ~/ 60, date % 60);
    return intl.DateFormat(format).format(time.toLocal());
  }

  static String getDisplayTextValue(dynamic val, String? format) {
    int? date = val is int? ? val : int.parse(val.toString());

    if (date == null) return '';
    var time = DateTime.utc(0, 0, 0, date ~/ 60, date % 60);
    return intl.DateFormat(format ?? 'HH:mm').format(time.toLocal());
  }

  static Widget getDisplay(dynamic value,
      [String? format, Color color = Colors.black, double size = 10]) {
    return Text(getDisplayTextValue(value, format),
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    // if (isTodayByDefault) {
    //   data[dbName] = DateTime.now().toUtc();
    //   return true;
    // }
    return false;
  }
}

==> tecfy_corev2_package-1.1.66.tar.gz: lib/models/entity/property_time.model.dart <==
part of tecfy_corev2_client_package;

class PropertyTime extends Property {
  /// <summary>
  /// HH:mm    (default)
  /// dd/MM/yyyy
  /// </summary>
  late String format;

  PropertyTime(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      bool readOnly = false,
      this.format = "HH:mm"})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            readOnly: readOnly,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyTime.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);

    //return Text(data[dbName]?.toString()?.substring(0,10) ?? '',style:TextStyle(fontSize: size,color:color));
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    var value = MapService.getValue(data, dbName);
    int? date = value is int ? value : int.tryParse(value?.toString() ?? '');

    if (date == null) return '';
    var time = DateTime.utc(0, 0, 0, date ~/ 60, date % 60);
    return intl.DateFormat(format).format(time.toLocal());
  }

  static String getDisplayTextValue(dynamic val, String? format) {
    int? date = val is int? ? val : int.parse(val.toString());

    if (date == null) return '';
    var time = DateTime.utc(0, 0, 0, date ~/ 60, date % 60);
    return intl.DateFormat(format ?? 'HH:mm').format(time.toLocal());
  }

  static Widget getDisplay(dynamic value,
      [String? format, Color color = Colors.black, double size = 10]) {
    return Text(getDisplayTextValue(value, format),
        style: TextStyle(fontSize: size, color: color));
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (MapService.getValue(data, dbName) != null) return false;
    // if (isTodayByDefault) {
    //   data[dbName] = DateTime.now().toUtc();
    //   return true;
    // }
    return false;
  }
}
